@@ -5,14 +5,14 @@ from io import BytesIO
 import logging
 import os.path
 
+from affine import Affine
+import numpy
 import pytest
 
 import rasterio
 from rasterio.io import MemoryFile, ZipMemoryFile
 from rasterio.env import GDALVersion
 
-logging.basicConfig(level=logging.DEBUG)
-
 
 # Skip ENTIRE module if not GDAL >= 2.x.
 # pytestmark is a keyword that instructs pytest to skip this module.
@@ -233,3 +233,27 @@ def test_vrt_memfile():
             assert src.count == 3
             assert src.dtypes == ('uint8', 'uint8', 'uint8')
             assert src.read().shape == (3, 768, 1024)
+
+
+def test_write_plus_mode():
+    with MemoryFile() as memfile:
+        with memfile.open(driver='GTiff', dtype='uint8', count=3, height=32, width=32, crs='epsg:3226', transform=Affine.identity() * Affine.scale(0.5, -0.5)) as dst:
+            dst.write(numpy.full((32, 32), 255, dtype='uint8'), 1)
+            dst.write(numpy.full((32, 32), 204, dtype='uint8'), 2)
+            dst.write(numpy.full((32, 32), 153, dtype='uint8'), 3)
+            data = dst.read()
+            assert (data[0] == 255).all()
+            assert (data[1] == 204).all()
+            assert (data[2] == 153).all()
+
+
+def test_write_plus_model_jpeg():
+    with MemoryFile() as memfile:
+        with memfile.open(driver='JPEG', dtype='uint8', count=3, height=32, width=32, crs='epsg:3226', transform=Affine.identity() * Affine.scale(0.5, -0.5)) as dst:
+            dst.write(numpy.full((32, 32), 255, dtype='uint8'), 1)
+            dst.write(numpy.full((32, 32), 204, dtype='uint8'), 2)
+            dst.write(numpy.full((32, 32), 153, dtype='uint8'), 3)
+            data = dst.read()
+            assert (data[0] == 255).all()
+            assert (data[1] == 204).all()
+            assert (data[2] == 153).all()
