@@ -6,7 +6,6 @@ from click.testing import CliRunner
 
 import rasterio
 from rasterio.rio.main import main_group
-from rasterio.rio.convert import convert
 
 
 logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
@@ -14,16 +13,33 @@ logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
 TEST_BBOX = [-11850000, 4804000, -11840000, 4808000]
 
 
+def bbox(*args):
+    return ' '.join([str(x) for x in args])
+
+
 def test_clip_bounds(runner, tmpdir):
     output = str(tmpdir.join('test.tif'))
     result = runner.invoke(
         main_group,
-        ['clip', 'tests/data/shade.tif', output, '--bounds'] + TEST_BBOX)
+        ['clip', 'tests/data/shade.tif', output, '--bounds', bbox(*TEST_BBOX)])
     assert result.exit_code == 0
     assert os.path.exists(output)
 
     with rasterio.open(output) as out:
-        assert out.shape == (420, 173)
+        assert out.shape == (419, 173)
+
+
+def test_clip_bounds_geographic(runner, tmpdir):
+    output = str(tmpdir.join('test.tif'))
+    result = runner.invoke(
+        main_group,
+        ['clip', 'tests/data/RGB.byte.tif', output, '--geographic', '--bounds',
+         '-78.95864996545055 23.564991210854686 -76.57492370013823 25.550873767433984'])
+    assert result.exit_code == 0
+    assert os.path.exists(output)
+
+    with rasterio.open(output) as out:
+        assert out.shape == (718, 791)
 
 
 def test_clip_like(runner, tmpdir):
@@ -53,7 +69,7 @@ def test_clip_bounds_disjunct(runner, tmpdir):
     output = str(tmpdir.join('test.tif'))
     result = runner.invoke(
         main_group,
-        ['clip', 'tests/data/shade.tif', output, '--bounds'] + [0, 0, 10, 10])
+        ['clip', 'tests/data/shade.tif', output, '--bounds', bbox(0, 0, 10, 10)])
     assert result.exit_code == 2
     assert '--bounds' in result.output
 
@@ -74,8 +90,8 @@ def test_format(tmpdir):
     outputname = str(tmpdir.join('test.jpg'))
     runner = CliRunner()
     result = runner.invoke(
-        convert,
-        ['tests/data/RGB.byte.tif', outputname, '--format', 'JPEG'])
+        main_group,
+        ['convert', 'tests/data/RGB.byte.tif', outputname, '--format', 'JPEG'])
     assert result.exit_code == 0
     with rasterio.open(outputname) as src:
         assert src.driver == 'JPEG'
@@ -85,8 +101,8 @@ def test_format_short(tmpdir):
     outputname = str(tmpdir.join('test.jpg'))
     runner = CliRunner()
     result = runner.invoke(
-        convert,
-        ['tests/data/RGB.byte.tif', outputname, '-f', 'JPEG'])
+        main_group,
+        ['convert', 'tests/data/RGB.byte.tif', outputname, '-f', 'JPEG'])
     assert result.exit_code == 0
     with rasterio.open(outputname) as src:
         assert src.driver == 'JPEG'
@@ -96,8 +112,8 @@ def test_output_opt(tmpdir):
     outputname = str(tmpdir.join('test.jpg'))
     runner = CliRunner()
     result = runner.invoke(
-        convert,
-        ['tests/data/RGB.byte.tif', '-o', outputname, '-f', 'JPEG'])
+        main_group,
+        ['convert', 'tests/data/RGB.byte.tif', '-o', outputname, '-f', 'JPEG'])
     assert result.exit_code == 0
     with rasterio.open(outputname) as src:
         assert src.driver == 'JPEG'
@@ -107,8 +123,8 @@ def test_dtype(tmpdir):
     outputname = str(tmpdir.join('test.tif'))
     runner = CliRunner()
     result = runner.invoke(
-        convert,
-        ['tests/data/RGB.byte.tif', outputname, '--dtype', 'uint16'])
+        main_group,
+        ['convert', 'tests/data/RGB.byte.tif', outputname, '--dtype', 'uint16'])
     assert result.exit_code == 0
     with rasterio.open(outputname) as src:
         assert src.dtypes == tuple(['uint16'] * 3)
@@ -119,8 +135,8 @@ def test_dtype_rescaling_uint8_full(tmpdir):
     outputname = str(tmpdir.join('test.tif'))
     runner = CliRunner()
     result = runner.invoke(
-        convert,
-        ['tests/data/RGB.byte.tif', outputname, '--scale-ratio', '1.0'])
+        main_group,
+        ['convert', 'tests/data/RGB.byte.tif', outputname, '--scale-ratio', '1.0'])
     assert result.exit_code == 0
 
     src_stats = [
@@ -139,8 +155,8 @@ def test_dtype_rescaling_uint8_half(tmpdir):
     """Rescale uint8 [0, 255] to uint8 [0, 127]"""
     outputname = str(tmpdir.join('test.tif'))
     runner = CliRunner()
-    result = runner.invoke(convert, [
-        'tests/data/RGB.byte.tif', outputname, '--scale-ratio', '0.5'])
+    result = runner.invoke(main_group, [
+        'convert', 'tests/data/RGB.byte.tif', outputname, '--scale-ratio', '0.5'])
     assert result.exit_code == 0
     with rasterio.open(outputname) as src:
         for band in src.read():
@@ -153,8 +169,8 @@ def test_dtype_rescaling_uint16(tmpdir):
     # NB: 255 * 16 is 4080, we don't actually get to 4095.
     outputname = str(tmpdir.join('test.tif'))
     runner = CliRunner()
-    result = runner.invoke(convert, [
-        'tests/data/RGB.byte.tif', outputname, '--dtype', 'uint16',
+    result = runner.invoke(main_group, [
+        'convert', 'tests/data/RGB.byte.tif', outputname, '--dtype', 'uint16',
         '--scale-ratio', '16'])
     assert result.exit_code == 0
     with rasterio.open(outputname) as src:
@@ -167,8 +183,8 @@ def test_dtype_rescaling_float64(tmpdir):
     """Rescale uint8 [0, 255] to float64 [-1, 1]"""
     outputname = str(tmpdir.join('test.tif'))
     runner = CliRunner()
-    result = runner.invoke(convert, [
-        'tests/data/RGB.byte.tif', outputname, '--dtype', 'float64',
+    result = runner.invoke(main_group, [
+        'convert', 'tests/data/RGB.byte.tif', outputname, '--dtype', 'float64',
         '--scale-ratio', str(2.0 / 255), '--scale-offset', '-1.0'])
     assert result.exit_code == 0
     with rasterio.open(outputname) as src:
@@ -181,8 +197,8 @@ def test_rgb(tmpdir):
     outputname = str(tmpdir.join('test.tif'))
     runner = CliRunner()
     result = runner.invoke(
-        convert,
-        ['tests/data/RGB.byte.tif', outputname, '--rgb'])
+        main_group,
+        ['convert', 'tests/data/RGB.byte.tif', outputname, '--rgb'])
     assert result.exit_code == 0
     with rasterio.open(outputname) as src:
-        assert src.colorinterp(1) == rasterio.enums.ColorInterp.red
+        assert src.colorinterp[0] == rasterio.enums.ColorInterp.red
