@@ -1,5 +1,3 @@
-
-import shutil
 import subprocess
 import re
 
@@ -8,6 +6,10 @@ import numpy as np
 import pytest
 
 import rasterio
+from rasterio.env import GDALVersion
+
+from .conftest import requires_gdal21
+
 
 def test_update_tags(data):
     tiffname = str(data.join('RGB.byte.tif'))
@@ -19,7 +21,7 @@ def test_update_tags(data):
         assert f.tags() == {'AREA_OR_POINT': 'Area', 'a': '1', 'b': '2'}
         assert ('c', '3') in f.tags(1).items()
     info = subprocess.check_output(["gdalinfo", tiffname]).decode('utf-8')
-    assert re.search("Metadata:\W+a=1\W+AREA_OR_POINT=Area\W+b=2", info)
+    assert re.search(r'Metadata:\W+a=1\W+AREA_OR_POINT=Area\W+b=2', info)
 
 
 def test_update_band(data):
@@ -33,26 +35,30 @@ def test_update_band(data):
 def test_update_spatial(data):
     tiffname = str(data.join('RGB.byte.tif'))
     with rasterio.open(tiffname, 'r+') as f:
-        f.transform = affine.Affine.from_gdal(1.0, 1.0, 0.0, 0.0, 0.0, -1.0)
+        f.transform = affine.Affine(1.0, 0.0, 1.0,
+                                    0.0, -1.0, 0.0)
         f.crs = {'init': 'epsg:4326'}
     with rasterio.open(tiffname) as f:
-        assert list(f.transform) == [1.0, 1.0, 0.0, 0.0, 0.0, -1.0]
-        assert list(f.affine.to_gdal()) == [1.0, 1.0, 0.0, 0.0, 0.0, -1.0]
+        assert f.transform == affine.Affine(1.0, 0.0, 1.0,
+                                            0.0, -1.0, 0.0)
+        assert f.transform.to_gdal() == (1.0, 1.0, 0.0, 0.0, 0.0, -1.0)
         assert f.crs == {'init': 'epsg:4326'}
 
 
 def test_update_spatial_epsg(data):
     tiffname = str(data.join('RGB.byte.tif'))
     with rasterio.open(tiffname, 'r+') as f:
-        f.transform = affine.Affine.from_gdal(1.0, 1.0, 0.0, 0.0, 0.0, -1.0)
+        f.transform = affine.Affine(1.0, 0.0, 1.0,
+                                    0.0, -1.0, 0.0)
         f.crs = 'EPSG:4326'
     with rasterio.open(tiffname) as f:
-        assert list(f.transform) == [1.0, 1.0, 0.0, 0.0, 0.0, -1.0]
-        assert list(f.affine.to_gdal()) == [1.0, 1.0, 0.0, 0.0, 0.0, -1.0]
+        assert f.transform == affine.Affine(1.0, 0.0, 1.0,
+                                            0.0, -1.0, 0.0)
+        assert f.transform.to_gdal() == (1.0, 1.0, 0.0, 0.0, 0.0, -1.0)
         assert f.crs == {'init': 'epsg:4326'}
 
 
-def test_update_nodatavals(data):
+def test_update_nodata(data):
     tiffname = str(data.join('RGB.byte.tif'))
     with rasterio.open(tiffname, 'r+') as f:
         f.nodata = 255
@@ -60,14 +66,25 @@ def test_update_nodatavals(data):
         assert f.nodatavals == (255, 255, 255)
 
 
-def test_update_nodatavals_error(data):
-    """GDAL doesn't support un-setting nodata values."""
+@pytest.mark.skipif(
+    GDALVersion.runtime().at_least('2.1'),
+    reason='Tests behavior specific to GDAL versions < 2.1')
+def test_update_nodatavals_none_fails(data):
+    """GDAL 2.0 doesn't support un-setting nodata values."""
     tiffname = str(data.join('RGB.byte.tif'))
     with rasterio.open(tiffname, 'r+') as f:
-        try:
+        with pytest.raises(NotImplementedError):
             f.nodata = None
-        except TypeError:
-            pass
+
+
+@requires_gdal21
+def test_update_nodatavals_none(data):
+    """GDAL 2.1 does support un-setting nodata values."""
+    tiffname = str(data.join('RGB.byte.tif'))
+    with rasterio.open(tiffname, 'r+') as f:
+        f.nodata = None
+    with rasterio.open(tiffname) as f:
+        assert f.nodatavals == (None, None, None)
 
 
 def test_update_mask_true(data):
